@@ -1,12 +1,11 @@
 package POE::Component::CPAN::YACSmoke;
+$POE::Component::CPAN::YACSmoke::VERSION = '1.38';
+#ABSTRACT: Bringing the power of POE to CPAN smoke testing.
 
 use strict;
 use warnings;
 use POE qw(Wheel::Run);
 use Storable;
-use vars qw($VERSION);
-
-$VERSION = '1.36';
 
 my $GOT_KILLFAM;
 
@@ -36,7 +35,7 @@ sub spawn {
   my $self = bless \%opts, $package;
   $self->{session_id} = POE::Session->create(
 	object_states => [
-	   $self => { shutdown  => '_shutdown', 
+	   $self => { shutdown  => '_shutdown',
 		      submit    => '_command',
 		      push      => '_command',
 		      unshift   => '_command',
@@ -297,7 +296,7 @@ sub _sig_child {
   }
   $job->{end_time} = time();
   unless ( $self->{debug} ) {
-    delete $job->{program}; 
+    delete $job->{program};
     delete $job->{program_args};
   }
   # Stats
@@ -545,31 +544,40 @@ sub _get_pids {
       if ($proc->ppid == $kid) {
 	my $pid = $proc->pid;
 	push @pids, $pid, _get_pids( $procs, $pid );
-      } 
+      }
     }
   }
   @pids;
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::CPAN::YACSmoke - Bringing the power of POE to CPAN smoke testing.
 
+=head1 VERSION
+
+version 1.38
+
 =head1 SYNOPSIS
 
   use strict;
   use POE qw(Component::CPAN::YACSmoke);
   use Getopt::Long;
-  
+
   $|=1;
-  
+
   my ($perl, $jobs);
-  
+
   GetOptions( 'perl=s' => \$perl, 'jobs=s' => \$jobs );
-  
+
   my @pending;
   if ( $jobs ) {
     open my $fh, "<$jobs" or die "$jobs: $!\n";
@@ -579,36 +587,36 @@ POE::Component::CPAN::YACSmoke - Bringing the power of POE to CPAN smoke testing
     }
     close($fh);
   }
-  
+
   my $smoker = POE::Component::CPAN::YACSmoke->spawn( alias => 'smoker' );
-  
+
   POE::Session->create(
-  	package_states => [
-  	   'main' => [ qw(_start _stop _results _recent) ],
-  	],
-  	heap => { perl => $perl, pending => \@pending },
+    package_states => [
+       'main' => [ qw(_start _stop _results _recent) ],
+    ],
+    heap => { perl => $perl, pending => \@pending },
   );
-  
+
   $poe_kernel->run();
   exit 0;
-  
+
   sub _start {
     my ($kernel,$heap) = @_[KERNEL,HEAP];
     if ( @{ $heap->{pending} } ) {
       $kernel->post( 'smoker', 'submit', { event => '_results', perl => $heap->{perl}, module => $_ } ) 
-  	for @{ $heap->{pending} };
+        for @{ $heap->{pending} };
     }
     else {
       $kernel->post( 'smoker', 'recent', { event => '_recent', perl => $heap->{perl} } ) 
     }
     undef;
   }
-  
+
   sub _stop {
     $poe_kernel->call( 'smoker', 'shutdown' );
     undef;
   }
-  
+
   sub _results {
     my $job = $_[ARG0];
     print STDOUT "Module: ", $job->{module}, "\n";
@@ -623,7 +631,6 @@ POE::Component::CPAN::YACSmoke - Bringing the power of POE to CPAN smoke testing
     undef;
   }
 
-  
 =head1 DESCRIPTION
 
 POE::Component::CPAN::YACSmoke is a POE-based framework around L<CPANPLUS> and L<CPAN::YACSmoke>.
@@ -717,7 +724,7 @@ The data is returned in the following order:
   The current average job run time;
   The minimum job run time observed;
   The maximum job run time observed;
-  
+
 =back
 
 =head1 INPUT EVENTS
@@ -796,7 +803,7 @@ possible future API clashes.
 
 =item C<check>
 
-Checks whether L<CPAN::YACSmoke> is installed. Takes one parameter a hashref with the following keys 
+Checks whether L<CPAN::YACSmoke> is installed. Takes one parameter a hashref with the following keys
 defined:
 
   'event', an event name for the results to be sent to (Mandatory);
@@ -805,7 +812,7 @@ defined:
 
 It is possible to pass arbitrary keys in the hash. These should be proceeded with an underscore to avoid
 possible future API clashes.
-  
+
 =item C<indices>
 
 Forces an update of the CPANPLUS indices. Takes one parameter, a hashref with the following keys defined:
@@ -849,16 +856,6 @@ used to fix the issues surrounding L<POE::Wheel::Run> and forking alternative co
 
 The code is still experimental though. Be warned.
 
-=head1 AUTHOR
-
-Chris 'BinGOs' Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 KUDOS
 
 Many thanks to all the people who have helped me with developing this module.
@@ -887,4 +884,15 @@ L<http://cpantest.grango.org/cgi-bin/pages.cgi?act=wiki-page&pagename=YACSmokePO
 
 L<http://use.perl.org/~BinGOs/journal/>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
